@@ -35,6 +35,6 @@ read.wand <- function(file='file name with path'){
   set.vertex.attribute(y,'storage',x[[5]])
   set.vertex.attribute(y,'output',x[[3]]+x[[4]])
   y%v%'vertex.names' <- vn
-  set.edge.attribute(x,'flow', flow.mat[flow.mat>0])
+  set.edge.attribute(y,'flow', flow.mat[flow.mat>0])
   return(y)
 }
